summaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/jogamp/opengl/GLDrawableFactoryImpl.java
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2015-01-23 15:10:20 +0100
committerSven Gothel <[email protected]>2015-01-23 15:10:20 +0100
commitec138f2f5c38a677d840e8719292031d91befaa8 (patch)
tree176ab71efb8fac231bf625f5deb3d7f38129a2fd /src/jogl/classes/jogamp/opengl/GLDrawableFactoryImpl.java
parent3471ee732ab1b642a37066c70acbb749eb696d21 (diff)
Simplify GLDrawable[Impl|Factory].getGLDynamicLookupHelper(..)
- Using GLDrawableFactory.getGLDynamicLookupHelper(String profileName) - Based on String GLProfile name - throws GLException if no lookup handler installed (EGL) - final implementation of GLDrawableImpl.getGLDynamicLookupHelper() using getGLProfile().getImplName()
Diffstat (limited to 'src/jogl/classes/jogamp/opengl/GLDrawableFactoryImpl.java')
-rw-r--r--src/jogl/classes/jogamp/opengl/GLDrawableFactoryImpl.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/jogl/classes/jogamp/opengl/GLDrawableFactoryImpl.java b/src/jogl/classes/jogamp/opengl/GLDrawableFactoryImpl.java
index ee984b74a..5078afd78 100644
--- a/src/jogl/classes/jogamp/opengl/GLDrawableFactoryImpl.java
+++ b/src/jogl/classes/jogamp/opengl/GLDrawableFactoryImpl.java
@@ -160,10 +160,11 @@ public abstract class GLDrawableFactoryImpl extends GLDrawableFactory {
/**
* Returns the GLDynamicLookupHelper
* @param profile if EGL/ES, profile <code>1</code> refers to ES1 and <code>2</code> to ES2,
* otherwise the profile is ignored.
+ * @throws GLException if no DynamicLookupHelper is installed
*/
- public abstract GLDynamicLookupHelper getGLDynamicLookupHelper(int profile);
+ public abstract GLDynamicLookupHelper getGLDynamicLookupHelper(final String profileName) throws GLException;
//---------------------------------------------------------------------------
// Dispatching GLDrawable construction in respect to the NativeSurface Capabilities
@@ -160,10 +160,11 @@ public abstract class GLDrawableFactoryImpl extends GLDrawableFactory {
/**
* Returns the GLDynamicLookupHelper
- * @param profile if EGL/ES, profile <code>1</code> refers to ES1 and <code>2</code> to ES2,
+ * @param profileName if EGL/ES, profile <code>1</code> refers to ES1 and <code>2</code> to ES2,
* otherwise the profile is ignored.